==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebComponentBoolValueChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebComponentBoolValueChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebComponentBoolValueChangedEventArgsDescription, _super);
    function WebComponentBoolValueChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.g = false;
        return _this;
    }
    WebComponentBoolValueChangedEventArgsDescription.prototype.get_type = function () {
        return "WebComponentBoolValueChangedEventArgs";
    };
    Object.defineProperty(WebComponentBoolValueChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebComponentBoolValueChangedEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
            this.e("Detail");
        },
        enumerable: true,
        configurable: true
    });
    WebComponentBoolValueChangedEventArgsDescription.$t = markType(WebComponentBoolValueChangedEventArgsDescription, 'WebComponentBoolValueChangedEventArgsDescription', Description.$);
    WebComponentBoolValueChangedEventArgsDescription.__marshalByValue = true;
    WebComponentBoolValueChangedEventArgsDescription.__marshalByValueAlias = "ComponentBoolValueChangedEventArgs";
    return WebComponentBoolValueChangedEventArgsDescription;
}(Description));
export { WebComponentBoolValueChangedEventArgsDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebComponentBoolValueChangedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebComponentBoolValueChangedEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebComponentBoolValueChangedEventArgsDescription, _super);
    function WebComponentBoolValueChangedEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.i = false;
        return _this;
    }
    WebComponentBoolValueChangedEventArgsDescription.prototype.get_type = function () {
        return "WebComponentBoolValueChangedEventArgs";
    };
    Object.defineProperty(WebComponentBoolValueChangedEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebComponentBoolValueChangedEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebComponentBoolValueChangedEventArgsDescription.$t = markType(WebComponentBoolValueChangedEventArgsDescription, 'WebComponentBoolValueChangedEventArgsDescription', Description.$);
    WebComponentBoolValueChangedEventArgsDescription.__marshalByValue = true;
    WebComponentBoolValueChangedEventArgsDescription.__marshalByValueAlias = "ComponentBoolValueChangedEventArgs";
    return WebComponentBoolValueChangedEventArgsDescription;
}(Description));
export { WebComponentBoolValueChangedEventArgsDescription };
